@@ -1,5 +1,4 @@
 from pactman.mock.pact import Pact as PactmanPact
-from pactman.verifier.result import LoggedResult, Result
 
 
 def create_pactman_pact(
@@ -13,11 +12,3 @@ def create_pactman_pact(
     consumer = {"name": consumer_name}
     provider = {"name": provider_name}
     return PactmanPact(consumer, provider, version=version)
-
-
-def result_factory() -> Result:
-    """
-    Returns a new Pactman Result object
-    """
-    # TODO: Replace this with a more helpful Result subclass
-    return LoggedResult()
